BarChart class

Inheritance
Available extensions

Constructors

BarChart({Key? key, double maxValue = 100, double minValue = 0, BGDefaultConfig defaultConfig = const BGDefaultConfig(), int? totalGroups, int? totalBarsPerGroup, List<Group>? groups, double interGroupSpace = 10, double axisBarSpace = 5, AxisLabelFn? axisLabel, PopUpFn? defaultPopUp, int axisTotalMiddleLabels = 0, Bar? emptyBar, Group? emptyGroup, int? maxBarsInGroup, int? maxGroups, bool showMinOnAxis = true, bool showMaxOnAxis = true, Direction direction = Direction.right, bool popUpCanOverflow = false, bool expandableBarThickness = false})
Creates Animated Horizontal Bar Chart.

Properties

axisBarSpace → double
This is the space between the axis and the bars.
final
axisLabel → AxisLabelFn
final
axisTotalMiddleLabels → int
Number of labels beside the minValue and maxValue to be displayed, i.e, number of labels to be displayed between the minValue and maxValue.
final
defaultConfig → BGDefaultConfig
final
direction → Direction
Direction of the bar graph, i.e either up, down, left, right. for example, in case of right, it means bars will start from left to right.
final
duration → Duration
final
emptyBar → FBar
final
emptyGroup → FGroup
final
expandableBarThickness → bool
If true, each bar's thickness will expand to its maximum capacity.
final
groups ↔ List<Group>
latefinal
hashCode → int
The hash code for this object.
no setterinherited
interGroupSpace → double
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
maxBarsInGroup ↔ int
latefinal
maxGroups ↔ int
latefinal
maxValue → double
final
minValue → double
final
popUpCanOverflow → bool
If set to true, then PopupScope will not be used, and pop-ups will be able to overflow outside of the chart.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showMaxOnAxis → bool
If false, then label corresponding to maxValue will not be displayed on the Axis.
final
showMinOnAxis → bool
If false, then label corresponding to minValue will not be displayed on the Axis.
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<BarChart>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
getBox(void fn(RenderBox box)) → Widget

Available on Widget, provided by the WidgetExt extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited