BarChartEngine class

Constructors

BarChartEngine(BarChart chart)

Properties

axisBox ← RenderBox
no getter
basePopUpConfig → BubblePopUpConfig
final
calcMaxCrossLength → double
This will calculate the maximum length of cross axis of bars.
no setter
direction → Direction
final
directionNp → NumPair
final
emptyBar ↔ FBar
getter/setter pair
emptyGroup → FGroup
final
flex → FlexConfig
final
gotAllGroupLabelSizes ↔ bool
getter/setter pair
groupLabelKeys → List<GlobalKey<State<StatefulWidget>>>
final
groupLabelMaxSpace ↔ double?
getter/setter pair
groups ↔ List<FGroup>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
interGroupSpace → double
final
isAxisBoxInferred → bool
no setter
isEmpty ↔ bool
latefinal
maxCrossLengthCalculable → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showAxis → bool
no setter
updateFrame → ValueNotifier<bool>
final

Methods

build() → void
didUpdateWidget(BarChart chart) → void
getGroup(int i) → (FGroup, AdditionalGroupConfigs)
getGroupBar(int i, int j) → (FGroup, FBar)
isBarEmpty(FBar bar) → bool
isGroupEmpty(FGroup group) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited