AxisConfig class

Constructors

AxisConfig({required Axis axis, required VerticalDirection verticalDirection, required TextDirection textDirection})
const

Properties

axis → Axis
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textDirection → TextDirection
final
verticalDirection → VerticalDirection
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited