FlexConfig class

Constructors

FlexConfig({required AxisConfig main, required AxisConfig cross})
const

Properties

cross → AxisConfig
final
hashCode → int
The hash code for this object.
no setterinherited
main → AxisConfig
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited