FBar class

Constructors

FBar(double value, DefaultBarConfig config)
const
FBar.from(Bar bar, BarConfig groupDefaults, DefaultBarConfig defaultConfig)

Properties

config → DefaultBarConfig
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → double
final

Methods

copyWith({double? value, DefaultBarConfig? config}) → FBar
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited