Direction class

Available extensions

Constructors

Direction(int x, int y)
const

Properties

flip → Direction

Available on Direction, provided by the BarDirectionExt extension

no setter
hashCode → int
The hash code for this object.
no setteroverride
np → NumPair

Available on Direction, provided by the BarDirectionExt extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
toAxis → Axis

Available on Direction, provided by the BarDirectionExt extension

no setter
toTextDirection → TextDirection

Available on Direction, provided by the BarDirectionExt extension

no setter
toVerticalDirection → VerticalDirection

Available on Direction, provided by the BarDirectionExt extension

no setter
x → int
final
y → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override

Constants

down → const Direction
left → const Direction
up → const Direction