BarConfig class

Constructors

BarConfig({double? width, Color? color, Color? bgColor, Color? popUpColor, PopUpFn? popUpFn, BorderRadiusGeometry? border, BorderRadiusGeometry? bgBorder, BorderRadius? popUpBorderRadius, BubblePopUpConfig? popUpConfig})
bgColor can be used to set the background color of the bar.
const
BarConfig.fold(List<BarConfig> configs)
Merges all provided configs, with first nonNull value for each parameter.

Properties

bgBorder → BorderRadiusGeometry?
final
bgColor → Color?
final
border → BorderRadiusGeometry?
final
color → Color?
final
hashCode → int
The hash code for this object.
no setterinherited
popUpBorderRadius → BorderRadius?
final
popUpColor → Color?
final
popUpConfig → BubblePopUpConfig?
Sets the various configuration for the Bubble Pop Up we are using. We recommend to play around with the configurations, to better get the idea.
final
popUpFn → PopUpFn?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited