DefaultBarConfig class

Constructors

DefaultBarConfig({double width = 10, Color color = Colors.green, Color bgColor = Colors.red, Color popUpColor = kDefaultPopUpColor, PopUpFn popUp = kDefaultPopUpFn, BorderRadiusGeometry border = kCircularBorder, BorderRadiusGeometry bgBorder = kCircularBorder, BorderRadius popUpBorderRadius = BorderRadius.zero, BubblePopUpConfig? popUpConfig})
Note: Recommended to ONLY provide popUpConfig if want to change pop-up and base anchor alignments, else, DON'T set it.
const

Properties

bgBorder → BorderRadiusGeometry
final
bgColor → Color
final
border → BorderRadiusGeometry
final
color → Color
final
hashCode → int
The hash code for this object.
no setterinherited
final
popUpBorderRadius → BorderRadius
final
popUpColor → Color
final
popUpConfig → BubblePopUpConfig?
Sets the various configuration for the Bubble Pop Up we are using. We recommend to play around with the configurations, to better get the idea.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
width → double
final

Methods

copyWith(BarConfig config) → DefaultBarConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

kDefaultPopUpFn(FGroup grp, FBar bar, int i, int j) → Widget