DefaultGroupConfig class

Constructors

DefaultGroupConfig({double labelBarSpace = 10, double interBarSpace = 5, GroupLabelFn label = kDefaultLabel})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
interBarSpace → double
final
label → GroupLabelFn
final
labelBarSpace → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith(GroupConfig config) → DefaultGroupConfig
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

kDefaultLabel(int index) → Widget