GroupConfig class

Constructors

GroupConfig({double? labelBarSpace, double? interBarSpace, GroupLabelFn? label})
const
GroupConfig.fold(List<GroupConfig> configs)
Merges all provided configs, with first nonNull value for each parameter.

Properties

hashCode → int
The hash code for this object.
no setterinherited
interBarSpace → double?
final
label → GroupLabelFn?
Parameter provided in this function, is the index of the group.
final
labelBarSpace → double?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited