FGroup class

Constructors

FGroup({required List<FBar> bars, BarConfig defaultBarConfig = const BarConfig(), required DefaultGroupConfig config})
const
FGroup.from(Group group, BGDefaultConfig defaultConfig)

Properties

bars → List<FBar>
final
config → DefaultGroupConfig
final
defaultBarConfig → BarConfig
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited
operator [](int index) → FBar?