Group class

Constructors

Group(List<Bar> bars, {GroupConfig config = const GroupConfig(), BarConfig defaultBarConfig = const BarConfig()})
Group of bars, packed together, under a single label.
const

Properties

bars → List<Bar>
final
config → GroupConfig
final
defaultBarConfig → BarConfig
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited